@@ -2,7 +2,7 @@
 #'
 #' @description
 #' Adds the necessary infrastructure to declare your package as licensed
-#' with one of four popular open source license:
+#' with one of these popular open source licenses:
 #'
 #' * [CC0](https://creativecommons.org/publicdomain/zero/1.0/): dedicated
 #'   to public domain. Appropriate for data packages.
@@ -11,6 +11,8 @@
 #'   provides patent protection.
 #' * [GPL v3](https://choosealicense.com/licenses/gpl-3.0/): requires sharing
 #'   of improvements.
+#' * [CCBY 4.0](https://creativecommons.org/licenses/by/4.0/): Free to share and
+#'    adapt, must give appropriate credit. Appropriate for data packages.
 #'
 #' See <https://choosealicense.com> for more details and other options.
 #'
@@ -23,6 +25,9 @@
 #' @param name Name of the copyright holder or holders. Separate multiple
 #'   individuals with `;`. You can supply a global default with
 #'   `options(usethis.full_name = "My name")`.
+#' @seealso The [license
+#'   section](https://r-pkgs.org/description.html#license) of [R
+#'   Packages](https://r-pkgs.org).
 #' @aliases NULL
 NULL
 
@@ -38,7 +43,7 @@ use_mit_license <- function(name = find_name()) {
   # Fill in template
   use_template(
     "license-mit.txt",
-    "LICENSE",
+    save_as = "LICENSE",
     data = license_data(name)
   )
 }
@@ -54,6 +59,16 @@ use_gpl3_license <- function(name = find_name()) {
   use_license_template("GPL-3", name)
 }
 
+#' @rdname licenses
+#' @export
+use_lgpl_license <- function(name = find_name()) {
+  force(name)
+  check_is_package("use_lgpl_license()")
+
+  use_description_field("License", "LGPL (>= 2.1)", overwrite = TRUE)
+  use_license_template("LGPL-2.1", name)
+}
+
 #' @rdname licenses
 #' @export
 use_apl2_license <- function(name = find_name()) {
@@ -74,13 +89,22 @@ use_cc0_license <- function(name = find_name()) {
   use_license_template("cc0", name)
 }
 
+#' @rdname licenses
+#' @export
+use_ccby_license <- function(name = find_name()) {
+  force(name)
+  check_is_package("use_ccby_license()")
+
+  use_description_field("License", "CCBY-4.0", overwrite = TRUE)
+  use_license_template("ccby-4", name)
+}
 
 use_license_template <- function(license, name) {
-  license_template <- paste0("license-", license, ".md")
+  license_template <- glue("license-{license}.md")
 
   use_template(
     license_template,
-    "LICENSE.md",
+    save_as = "LICENSE.md",
     data = license_data(name),
     ignore = TRUE
   )
@@ -96,20 +120,21 @@ license_data <- function(name, base_path = proj_get()) {
 
 
 find_name <- function() {
-  name <- getOption("devtools.name")
-  if (!is.null(name) && name != "Your name goes here") {
-    return(name)
-  }
-
   name <- getOption("usethis.full_name")
   if (!is.null(name)) {
     return(name)
   }
 
-  stop(
-    code("name"), " argument is missing.\n",
-    "Set it globally with ", code('options(usethis.full_name = "My name")'),
-    ", probably in your ", value(".Rprofile"),
-    call. = FALSE
+  name <- getOption("devtools.name")
+  if (!is.null(name) && name != "Your name goes here") {
+    return(name)
+  }
+
+  ui_stop(
+    "
+    {ui_code('name')} argument is missing.
+    Set it globally with {ui_code('options(usethis.full_name = \"My name\")')}\\
+    probably in your {ui_path('.Rprofile')}.
+    "
   )
 }
